==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
export let CalculatedColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalculatedColumnDescriptionMetadata extends Base {
        static b(a) {
            if (CalculatedColumnDescriptionMetadata.a == null) {
                CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
            }
            if (a.j(CalculatedColumnDescriptionMetadata.a)) {
                return;
            }
            a.y(CalculatedColumnDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CalculatedColumnDescriptionMetadata.b(a);
            a.aa("CalculatedColumn", () => new CalculatedColumnDescription());
            a.z("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
        }
    }
    CalculatedColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
export let CalculatedColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalculatedColumnDescriptionMetadata extends Base {
        static b(a) {
            if (CalculatedColumnDescriptionMetadata.a == null) {
                CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
            }
            if (a.k(CalculatedColumnDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalculatedColumnDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            CalculatedColumnDescriptionMetadata.b(a);
            a.ac("CalculatedColumn", () => new CalculatedColumnDescription());
            a.ab("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
        }
    }
    CalculatedColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
})();
